@@ -7,11 +7,13 @@ use Carp;
 
 use Search::Xapian::Database;
 use Search::Xapian::Document;
-use Search::Xapian::Enquire;
 use Search::Xapian::MSet;
 use Search::Xapian::MSetIterator;
 use Search::Xapian::Query;
 use Search::Xapian::WritableDatabase;
+use Search::Xapian::ESet;
+use Search::Xapian::ESetIterator;
+use Search::Xapian::RSet;
 
 require Exporter;
 require DynaLoader;
@@ -41,6 +43,8 @@ our %EXPORT_TAGS = (
                     'db' => [ qw(
                                  OM_DB_OPEN
                                  OM_DB_CREATE
+                                 OM_DB_CREATE_OR_OPEN
+                                 OM_DB_CREATE_OR_OVERWRITE
                                  ) ]
                    );
 $EXPORT_TAGS{standard} = [ @{ $EXPORT_TAGS{'ops'} }, @{ $EXPORT_TAGS{'db'} } ];
@@ -52,7 +56,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 bootstrap Search::Xapian $VERSION;
 
@@ -87,23 +91,23 @@ Search::Xapian - Perl XS frontend to the Xapian C++ search library.
 
 =head1 DESCRIPTION
 
-This module provides access to most of the classes in the xapian
-library, as well as a more simplified, 'perlish' interface - as
-demonstrated above.
+This module wraps most methods of most Xapian classes. The missing classes
+and methods should be added in the future. It also provides  a more
+simplified, 'perlish' interface - as demonstrated above.
 
-The xapian library is evolving very quickly at the time of writing,
+The Xapian library is evolving very quickly at the time of writing,
 hence any documentation placed here would be likely to become out of
 date quite rapidly, and I do not have the patience to write some which
 could rapidly become redundant.
 
 Apologies to those of you considering using this module. For the time
 being, I would suggest garnering what you can from the tests and
-examples provided with this module, or reading through the xapian
-documentation on http://www.xapian.org/.
+examples provided, or reading through the Xapian documentation on
+http://www.xapian.org/.
 
 If you encounter problems, email either me or preferably the
-xapian-discuss mailing list (which I am on - subscription details can
-be found on the xapian web site).
+Xapian-discuss mailing list (which I am on - subscription details can
+be found on the Xapian web site).
 
 =head2 EXPORT
 
@@ -119,7 +123,16 @@ Error handling for all method liable to generate them.
 
 =item Documentation
 
-Brief descriptions of classes, possibly just adapted for xapian docs.
+Brief descriptions of classes, possibly just adapted for Xapian docs.
+
+=head1 CREDITS
+
+Thanks to Tye McQueen E<lt>tye@metronet.comE<gt> for explaining the
+finer points of how best to write XS frontends to C++ libraries, James
+Aylett E<lt>james@tartarus.orgE<gt> for clarifying the less obvious
+aspects of the Xapian API, and Olly Betts E<lt>olly@survex.comE<gt>
+for contributing advice, bugfixes, and code wrapping some of the
+remaining classes.
 
 =head1 AUTHOR
 
